translate.misc.wsgi

Package translate :: Package misc :: Module wsgi |
[hide private]
[frames] | no frames]

# Module wsgi

source code

wrapper tht tries to pick the best available wsgi server

Functions | [hide private]
launch_server_wsgiref(host, port, app) use python's builtin simple_server, this is a last resort since it doesn't support concurrency at all | source code
launch_server_django(host, port, app) use django's development server, only works for django apps | source code
launch_server_cherrypy(host, port, app) use cherrypy's wsgiserver, a multithreaded scallable server | source code
launch_server_werkzeug(host, port, app) use werkzeug's simple multiprocess multithreaded server | source code
launch_server(host, port, app) use the best possible wsgi server | source code

Variables | [hide private]
| servers = `[launch_server_cherrypy, launch_server_werkzeug, lau`...``
| __package__ = ``'``translate.misc``'``

Imports: logging, os

Variables Details | [hide private]

  ### servers Value:
      [launch_server_cherrypy, launch_server_werkzeug, launch_server_django,
       launch_server_wsgiref]